@@ -12,6 +12,9 @@ pub enum Error {
     #[error("Error while accessing filesystem: {0:?}.")]
     IOError(std::io::Error),
 
+    #[error("Error in cache system: {0:?}.")]
+    CacheError(cached_path::Error),
+
     #[error("Script exited with code {0}.")]
     ErrorCode(u64),
 
@@ -35,6 +38,12 @@ impl From<std::io::Error> for Error {
     }
 }
 
+impl From<cached_path::Error> for Error {
+    fn from(e: cached_path::Error) -> Self {
+        Error::CacheError(e)
+    }
+}
+
 impl From<hyper::Error> for Error {
     fn from(e: hyper::Error) -> Self {
         Error::ConnectionError(e)
