@@ -3,13 +3,16 @@
 //! like a YAML script. Therefore, this library is also capable of building a
 //! remote runner service.
 
-pub mod asset;
+mod asset;
 mod error;
-pub mod reporter;
+mod reporter;
 pub mod runner;
 pub mod sandbox;
 mod task;
 
+pub use asset::AssetManager;
 pub use error::Error;
+pub use reporter::Reporter;
 pub use runner::Runner;
+pub use sandbox::Sandbox;
 pub use task::Task;
