@@ -1,13 +1,9 @@
-//! Reporting running status and logs.
-
 use chrono::{DateTime, Utc};
 
-use crate::{runner::Status, Error};
+use crate::Error;
 
+/// Reporting running status and logs
 pub trait Reporter {
-    fn emit_status(&self, status: &Status) -> Result<(), Error> {
-        self.report_status(status, Utc::now())
-    }
     fn emit_stdout(&self, line: &str) -> Result<(), Error> {
         let (ts, line) = line.split_once(' ').expect("expect to timestamp");
         let timestamp =
@@ -21,7 +17,6 @@ pub trait Reporter {
         self.report_stderr(line.trim_end(), timestamp.into())
     }
 
-    fn report_status(&self, status: &Status, timestamp: DateTime<Utc>) -> Result<(), Error>;
     fn report_stdout(&self, line: &str, timestamp: DateTime<Utc>) -> Result<(), Error>;
     fn report_stderr(&self, line: &str, timestamp: DateTime<Utc>) -> Result<(), Error>;
 }
@@ -29,12 +24,6 @@ pub trait Reporter {
 pub struct TextReporter;
 
 impl Reporter for TextReporter {
-    fn report_status(&self, status: &Status, _: DateTime<Utc>) -> Result<(), Error> {
-        if let Status::Error(e) = status {
-            log::warn!("error: {:?}", e);
-        }
-        Ok(())
-    }
     fn report_stdout(&self, line: &str, _: DateTime<Utc>) -> Result<(), Error> {
         println!("{}", line);
         Ok(())
